@@ -213,6 +213,7 @@ class SchemaOpts:
             raise ValueError("`exclude` must be a list or tuple.")
         self.dateformat = getattr(meta, "dateformat", None)
         self.datetimeformat = getattr(meta, "datetimeformat", None)
+        self.timeformat = getattr(meta, "timeformat", None)
         if hasattr(meta, "json_module"):
             warnings.warn(
                 "The json_module class Meta option is deprecated. Use render_module instead.",
@@ -345,6 +346,7 @@ class Schema(base.SchemaABC, metaclass=SchemaMeta):
             Nested fields can be represented with dot delimiters.
         - ``dateformat``: Default format for `Date <fields.Date>` fields.
         - ``datetimeformat``: Default format for `DateTime <fields.DateTime>` fields.
+        - ``timeformat``: Default format for `Time <fields.Time>` fields.
         - ``render_module``: Module to use for `loads <Schema.loads>` and `dumps <Schema.dumps>`.
             Defaults to `json` from the standard library.
         - ``ordered``: If `True`, order serialization output according to the
@@ -365,14 +367,14 @@ class Schema(base.SchemaABC, metaclass=SchemaMeta):
     def __init__(
         self,
         *,
-        only: types.StrSequenceOrSet = None,
+        only: typing.Optional[types.StrSequenceOrSet] = None,
         exclude: types.StrSequenceOrSet = (),
         many: bool = False,
-        context: typing.Dict = None,
+        context: typing.Optional[typing.Dict] = None,
         load_only: types.StrSequenceOrSet = (),
         dump_only: types.StrSequenceOrSet = (),
         partial: typing.Union[bool, types.StrSequenceOrSet] = False,
-        unknown: str = None
+        unknown: typing.Optional[str] = None
     ):
         # Raise error if only or exclude is passed as string, not list of strings
         if only is not None and not is_collection(only):
@@ -525,7 +527,7 @@ class Schema(base.SchemaABC, metaclass=SchemaMeta):
             ret[key] = value
         return ret
 
-    def dump(self, obj: typing.Any, *, many: bool = None):
+    def dump(self, obj: typing.Any, *, many: typing.Optional[bool] = None):
         """Serialize an object to native Python data types according to this
         Schema's fields.
 
@@ -563,7 +565,9 @@ class Schema(base.SchemaABC, metaclass=SchemaMeta):
 
         return result
 
-    def dumps(self, obj: typing.Any, *args, many: bool = None, **kwargs):
+    def dumps(
+        self, obj: typing.Any, *args, many: typing.Optional[bool] = None, **kwargs
+    ):
         """Same as :meth:`dump`, except return a JSON-encoded string.
 
         :param obj: The object to serialize.
@@ -696,9 +700,9 @@ class Schema(base.SchemaABC, metaclass=SchemaMeta):
             typing.Iterable[typing.Mapping[str, typing.Any]],
         ],
         *,
-        many: bool = None,
-        partial: typing.Union[bool, types.StrSequenceOrSet] = None,
-        unknown: str = None
+        many: typing.Optional[bool] = None,
+        partial: typing.Optional[typing.Union[bool, types.StrSequenceOrSet]] = None,
+        unknown: typing.Optional[str] = None
     ):
         """Deserialize a data structure to an object defined by this Schema's fields.
 
@@ -728,9 +732,9 @@ class Schema(base.SchemaABC, metaclass=SchemaMeta):
         self,
         json_data: str,
         *,
-        many: bool = None,
-        partial: typing.Union[bool, types.StrSequenceOrSet] = None,
-        unknown: str = None,
+        many: typing.Optional[bool] = None,
+        partial: typing.Optional[typing.Union[bool, types.StrSequenceOrSet]] = None,
+        unknown: typing.Optional[str] = None,
         **kwargs
     ):
         """Same as :meth:`load`, except it takes a JSON string as input.
@@ -780,8 +784,8 @@ class Schema(base.SchemaABC, metaclass=SchemaMeta):
         self,
         data: typing.Mapping,
         *,
-        many: bool = None,
-        partial: typing.Union[bool, types.StrSequenceOrSet] = None
+        many: typing.Optional[bool] = None,
+        partial: typing.Optional[typing.Union[bool, types.StrSequenceOrSet]] = None
     ) -> typing.Dict[str, typing.List[str]]:
         """Validate `data` against the schema, returning a dictionary of
         validation errors.
@@ -812,9 +816,9 @@ class Schema(base.SchemaABC, metaclass=SchemaMeta):
             typing.Iterable[typing.Mapping[str, typing.Any]],
         ],
         *,
-        many: bool = None,
-        partial: typing.Union[bool, types.StrSequenceOrSet] = None,
-        unknown: str = None,
+        many: typing.Optional[bool] = None,
+        partial: typing.Optional[typing.Union[bool, types.StrSequenceOrSet]] = None,
+        unknown: typing.Optional[str] = None,
         postprocess: bool = True
     ):
         """Deserialize `data`, returning the deserialized result.
